Function to translate columns that "should" be numeric into numeric but doesn't do so if that would mean converting a true character string to NA.
Function to translate columns that "should" be numeric into numeric but doesn't do so if that would mean converting a true character string to NA.